Update smo deployment with ICS

change of ECS to ICS

Signed-off-by: ecaiyanlinux <martin.c.yan@est.tech>
Issue-ID: NONRTRIC-625
Change-Id: Ic7f10b97f172d10f4bbd7f801567a4cdeaa99441
diff --git a/solution/integration/smo/non-rt-ric/.env b/solution/integration/smo/non-rt-ric/.env
index 0223a4c..fb58a4a 100644
--- a/solution/integration/smo/non-rt-ric/.env
+++ b/solution/integration/smo/non-rt-ric/.env
@@ -35,9 +35,9 @@
 NONRTRIC_GATEWAY_IMAGE_BASE="nexus3.o-ran-sc.org:10002/o-ran-sc/nonrtric-gateway"
 NONRTRIC_GATEWAY_IMAGE_TAG="1.0.0"
 
-#ECS
-ECS_IMAGE_BASE="nexus3.o-ran-sc.org:10002/o-ran-sc/nonrtric-enrichment-coordinator-service"
-ECS_IMAGE_TAG="1.1.0"
+#ICS
+ICS_IMAGE_BASE="nexus3.o-ran-sc.org:10002/o-ran-sc/nonrtric-information-coordinator-service"
+ICS_IMAGE_TAG="1.1.0"
 
 #PRODUCER
 PRODUCER_IMAGE_BASE="eexit/mirror-http-server"
diff --git a/solution/integration/smo/non-rt-ric/config/nonrtric-gateway/application-nonrtricgateway.yaml b/solution/integration/smo/non-rt-ric/config/nonrtric-gateway/application-nonrtricgateway.yaml
index 08b386c..d4d93be 100644
--- a/solution/integration/smo/non-rt-ric/config/nonrtric-gateway/application-nonrtricgateway.yaml
+++ b/solution/integration/smo/non-rt-ric/config/nonrtric-gateway/application-nonrtricgateway.yaml
@@ -31,11 +31,11 @@
         predicates:
         - Path=/a1-policy/**
       - id: A1-EI
-        uri: http://ecs:8083
+        uri: http://ics:8083
         predicates:
         - Path=/ei-producer/**
       - id: A1-EI2
-        uri: http://ecs:8083
+        uri: http://ics:8083
         predicates:
         - Path=/data-producer/**,/data-consumer/**
 management:
diff --git a/solution/integration/smo/non-rt-ric/data/prepareEcsData.sh b/solution/integration/smo/non-rt-ric/data/prepareEcsData.sh
deleted file mode 100755
index 6224f75..0000000
--- a/solution/integration/smo/non-rt-ric/data/prepareEcsData.sh
+++ /dev/null
@@ -1,89 +0,0 @@
-#!/bin/bash
-
-#  ============LICENSE_START===============================================
-#  Copyright (C) 2020 Nordix Foundation. All rights reserved.
-#  ========================================================================
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#       http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
-#  ============LICENSE_END=================================================
-#
-
-# The scripts in data/ will generate some dummy data in the running system.
-# It will create:
-# one EiProducer in ECS
-# one EiType in ECS
-# one EiJob in ECS
-
-# Run command:
-# ./prepareEcsData.sh [ECS port] [http/https]
-
-ecs_port=${1:-8083}
-httpx=${2:-"http"}
-SHELL_FOLDER=$(cd "$(dirname "$0")";pwd)
-
-echo "using ecs port: "$ecs_port
-echo "using protocol: "$httpx
-echo -e "\n"
-
-echo "ECS status:"
-curl -skw " %{http_code}" $httpx://localhost:$ecs_port/status
-echo -e "\n"
-
-# Create EiType
-echo "Create EiType:"
-curl -X PUT -skw %{http_code} $httpx://localhost:$ecs_port/data-producer/v1/info-types/type1 -H accept:application/json -H Content-Type:application/json --data-binary @${SHELL_FOLDER}/testdata/ECS/EiType.json
-echo -e "\n"
-
-# Get EiTypes
-echo "Get EiTypes:"
-curl -X GET -skw %{http_code} $httpx://localhost:$ecs_port/data-producer/v1/info-types -H Content-Type:application/json | jq
-echo -e "\n"
-
-# Get Individual EiType
-echo "Get Individual EiType:"
-curl -X GET -skw %{http_code} $httpx://localhost:$ecs_port/data-producer/v1/info-types/type1 -H Content-Type:application/json | jq
-echo -e "\n"
-
-# Create EiProducer
-echo "Create EiProducer:"
-curl -X PUT -skw %{http_code} $httpx://localhost:$ecs_port/data-producer/v1/info-producers/1 -H Content-Type:application/json --data-binary @${SHELL_FOLDER}/testdata/ECS/EiProducer.json
-echo -e "\n"
-
-# Get EiProducers
-echo "Get EiProducers:"
-curl -X GET -skw %{http_code} $httpx://localhost:$ecs_port/data-producer/v1/info-producers -H Content-Type:application/json | jq
-echo -e "\n"
-
-# Get Individual EiProducer
-echo "Get Individual EiProducer:"
-curl -X GET -skw %{http_code} $httpx://localhost:$ecs_port/data-producer/v1/info-producers/1 -H Content-Type:application/json | jq
-echo -e "\n"
-
-# Get Individual EiProducer Status
-echo "Get Individual EiProducer:"
-curl -X GET -skw %{http_code} $httpx://localhost:$ecs_port/data-producer/v1/info-producers/1/status -H Content-Type:application/json | jq
-echo -e "\n"
-
-# Create EiJob
-echo "Create EiJob Of A Certain Type type1:"
-curl -X PUT -skw %{http_code} $httpx://localhost:$ecs_port/A1-EI/v1/eijobs/job1 -H Content-Type:application/json --data-binary @${SHELL_FOLDER}/testdata/ECS/EiJob.json
-echo -e "\n"
-
-# Get EiJobs
-echo "Get EiJobs:"
-curl -X GET -skw %{http_code} $httpx://localhost:$ecs_port/A1-EI/v1/eijobs -H Content-Type:application/json | jq
-echo -e "\n"
-
-# Get Individual EiJob:
-echo "Get Individual EiJob:"
-curl -X GET -skw %{http_code} $httpx://localhost:$ecs_port/A1-EI/v1/eijobs/job1 -H Content-Type:application/json | jq
-echo -e "\n"
\ No newline at end of file
diff --git a/solution/integration/smo/non-rt-ric/data/prepareIcsData.sh b/solution/integration/smo/non-rt-ric/data/prepareIcsData.sh
new file mode 100755
index 0000000..c407140
--- /dev/null
+++ b/solution/integration/smo/non-rt-ric/data/prepareIcsData.sh
@@ -0,0 +1,89 @@
+#!/bin/bash
+
+#  ============LICENSE_START===============================================
+#  Copyright (C) 2020 Nordix Foundation. All rights reserved.
+#  ========================================================================
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
+#  ============LICENSE_END=================================================
+#
+
+# The scripts in data/ will generate some dummy data in the running system.
+# It will create:
+# one InfoProducer in ICS
+# one InfoType in ICS
+# one InfoJob in ICS
+
+# Run command:
+# ./prepareIcsData.sh [ICS port] [http/https]
+
+ics_port=${1:-8083}
+httpx=${2:-"http"}
+SHELL_FOLDER=$(cd "$(dirname "$0")";pwd)
+
+echo "using ics port: "$ics_port
+echo "using protocol: "$httpx
+echo -e "\n"
+
+echo "ICS status:"
+curl -skw " %{http_code}" $httpx://localhost:$ics_port/status
+echo -e "\n"
+
+# Create InfoType
+echo "Create InfoType:"
+curl -X PUT -skw %{http_code} $httpx://localhost:$ics_port/data-producer/v1/info-types/type1 -H accept:application/json -H Content-Type:application/json --data-binary @${SHELL_FOLDER}/testdata/ICS/InfoType.json
+echo -e "\n"
+
+# Get InfoTypes
+echo "Get InfoTypes:"
+curl -X GET -skw %{http_code} $httpx://localhost:$ics_port/data-producer/v1/info-types -H Content-Type:application/json | jq
+echo -e "\n"
+
+# Get Individual InfoType
+echo "Get Individual InfoType:"
+curl -X GET -skw %{http_code} $httpx://localhost:$ics_port/data-producer/v1/info-types/type1 -H Content-Type:application/json | jq
+echo -e "\n"
+
+# Create InfoProducer
+echo "Create InfoProducer:"
+curl -X PUT -skw %{http_code} $httpx://localhost:$ics_port/data-producer/v1/info-producers/1 -H Content-Type:application/json --data-binary @${SHELL_FOLDER}/testdata/ICS/InfoProducer.json
+echo -e "\n"
+
+# Get InfoProducers
+echo "Get InfoProducers:"
+curl -X GET -skw %{http_code} $httpx://localhost:$ics_port/data-producer/v1/info-producers -H Content-Type:application/json | jq
+echo -e "\n"
+
+# Get Individual InfoProducer
+echo "Get Individual InfoProducer:"
+curl -X GET -skw %{http_code} $httpx://localhost:$ics_port/data-producer/v1/info-producers/1 -H Content-Type:application/json | jq
+echo -e "\n"
+
+# Get Individual InfoProducer Status
+echo "Get Individual InfoProducer:"
+curl -X GET -skw %{http_code} $httpx://localhost:$ics_port/data-producer/v1/info-producers/1/status -H Content-Type:application/json | jq
+echo -e "\n"
+
+# Create InfoJob
+echo "Create InfoJob Of A Certain Type type1:"
+curl -X PUT -skw %{http_code} $httpx://localhost:$ics_port/A1-EI/v1/eijobs/job1 -H Content-Type:application/json --data-binary @${SHELL_FOLDER}/testdata/ICS/InfoJob.json
+echo -e "\n"
+
+# Get InfoJobs
+echo "Get InfoJobs:"
+curl -X GET -skw %{http_code} $httpx://localhost:$ics_port/A1-EI/v1/eijobs -H Content-Type:application/json | jq
+echo -e "\n"
+
+# Get Individual InfoJob:
+echo "Get Individual InfoJob:"
+curl -X GET -skw %{http_code} $httpx://localhost:$ics_port/A1-EI/v1/eijobs/job1 -H Content-Type:application/json | jq
+echo -e "\n"
\ No newline at end of file
diff --git a/solution/integration/smo/non-rt-ric/data/testdata/ECS/EiJob.json b/solution/integration/smo/non-rt-ric/data/testdata/ICS/InfoJob.json
similarity index 100%
rename from solution/integration/smo/non-rt-ric/data/testdata/ECS/EiJob.json
rename to solution/integration/smo/non-rt-ric/data/testdata/ICS/InfoJob.json
diff --git a/solution/integration/smo/non-rt-ric/data/testdata/ECS/EiProducer.json b/solution/integration/smo/non-rt-ric/data/testdata/ICS/InfoProducer.json
similarity index 100%
rename from solution/integration/smo/non-rt-ric/data/testdata/ECS/EiProducer.json
rename to solution/integration/smo/non-rt-ric/data/testdata/ICS/InfoProducer.json
diff --git a/solution/integration/smo/non-rt-ric/data/testdata/ECS/EiType.json b/solution/integration/smo/non-rt-ric/data/testdata/ICS/InfoType.json
similarity index 100%
rename from solution/integration/smo/non-rt-ric/data/testdata/ECS/EiType.json
rename to solution/integration/smo/non-rt-ric/data/testdata/ICS/InfoType.json
diff --git a/solution/integration/smo/non-rt-ric/docker-compose.yml b/solution/integration/smo/non-rt-ric/docker-compose.yml
index ef7b9d0..a367eff 100644
--- a/solution/integration/smo/non-rt-ric/docker-compose.yml
+++ b/solution/integration/smo/non-rt-ric/docker-compose.yml
@@ -117,9 +117,9 @@
     volumes:
       - ./config/nonrtric-gateway/application-nonrtricgateway.yaml:/opt/app/nonrtric-gateway/config/application.yaml:ro
 
-  ecs:
-    image: "${ECS_IMAGE_BASE}:${ECS_IMAGE_TAG}"
-    container_name: ecs
+  ics:
+    image: "${ICS_IMAGE_BASE}:${ICS_IMAGE_TAG}"
+    container_name: ics
     networks:
       - default
     ports:
diff --git a/solution/integration/smo/non-rt-ric/test/pms_a1sim.sh b/solution/integration/smo/non-rt-ric/test/pms_a1sim.sh
index db61592..38c7e04 100755
--- a/solution/integration/smo/non-rt-ric/test/pms_a1sim.sh
+++ b/solution/integration/smo/non-rt-ric/test/pms_a1sim.sh
@@ -62,6 +62,6 @@
 
 cd ${SHELL_FOLDER}/../data
 ./preparePmsData.sh
-./prepareEcsData.sh
+./prepareIcsData.sh
 
 
diff --git a/solution/integration/smo/non-rt-ric/test/pms_a1sim_sdnc.sh b/solution/integration/smo/non-rt-ric/test/pms_a1sim_sdnc.sh
index c3c4923..cbd1024 100755
--- a/solution/integration/smo/non-rt-ric/test/pms_a1sim_sdnc.sh
+++ b/solution/integration/smo/non-rt-ric/test/pms_a1sim_sdnc.sh
@@ -66,4 +66,4 @@
 
 cd ${SHELL_FOLDER}/../data
 ./preparePmsData.sh
-./prepareEcsData.sh
+./prepareIcsData.sh
diff --git a/solution/integration/smo/non-rt-ric/test/health_check.sh b/solution/integration/smo/non-rt-ric/test/health_check.sh
index 8ccd627..537a20f 100755
--- a/solution/integration/smo/non-rt-ric/test/health_check.sh
+++ b/solution/integration/smo/non-rt-ric/test/health_check.sh
@@ -64,8 +64,8 @@
 echo "check PMS status:"
 checkStatus "curl -skw %{http_code} http://localhost:8091/status" "hunky dory200" "PMS"
 
-# check ECS status
-echo "check ECS status:"
-checkStatus "curl -skw %{http_code} http://localhost:8083/status" '{"status":"hunky dory","no_of_producers":0,"no_of_types":0,"no_of_jobs":0}200' "ECS"
+# check ICS status
+echo "check ICS status:"
+checkStatus "curl -skw %{http_code} http://localhost:8083/status" '{"status":"hunky dory","no_of_producers":0,"no_of_types":0,"no_of_jobs":0}200' "ICS"
 
 echo "NONRTRIC health check passed."